@@ -18,13 +18,11 @@ package EBox::Printers;
 use strict;
 use warnings;
 
-use base qw(EBox::GConfModule EBox::FirewallObserver EBox::LogObserver
-			EBox::ServiceModule::ServiceInterface);
+use base qw(EBox::Module::Service EBox::FirewallObserver EBox::LogObserver);
 
 use EBox::Gettext;
 use EBox::Config;
 use EBox::Service;
-use EBox::Summary::Module;
 use EBox::Menu::Folder;
 use EBox::Menu::Item;
 use EBox::Exceptions::InvalidData;
@@ -42,18 +40,20 @@ use Net::CUPS;
 use Storable;
 
 use constant MAXPRINTERLENGHT 	=> 10;
-use constant SUPPORTEDMETHODS 	=> ('usb', 'parallel', 'network', 'samba');
+use constant SUPPORTEDMETHODS 	=> ('usb', 'parallel', 'network',
+                                    'samba', 'lpd', 'ipp',
+                                   );
 use constant CUPSPRINTERS     	=> '/etc/cups/printers.conf';
 use constant CUPSD              => '/etc/cups/cupsd.conf';
 use constant CUPSPPD 		=> '/etc/cups/ppd/';
 use constant START_TAG		=> '# __EBOX__ TAG #';
 use constant END_TAG		=> '# END __EBOX__ TAG #';
-	
-sub _create 
+
+sub _create
 {
 	my $class = shift;
-	my $self = $class->SUPER::_create(name => 'printers', 
-					  printableName => __('printers'),
+	my $self = $class->SUPER::_create(name => 'printers',
+					  printableName => __('Printer Sharing'),
 					  domain => 'ebox-printers' );
 	bless($self, $class);
 	$self->{'cups'} = new Net::CUPS;
@@ -62,29 +62,29 @@ sub _create
 
 sub domain
 {
-	return 'ebox-printers';	
+	return 'ebox-printers';
 }
 
 # Method: actions
 #
-# 	Override EBox::ServiceModule::ServiceInterface::actions
+# 	Override EBox::Module::Service::actions
 #
 sub actions
 {
-	return [ 
+	return [
 	{
 		'action' => __('Create spool directory for printers'),
 		'reason' => __('eBox will create a spool directory ' .
 						'under /var/spool/samba'),
 		'module' => 'printers'
 	},
-	{	
+	{
 		'action' => __('Add user ebox to lpadmin group'),
 		'reason' => __('In order to manage printers and queues from the ' .
                        'eBox web interface'),
 		'module' => 'printers'
 	},
-	{	
+	{
 		'action' => __('Create log table'),
 		'reason' => __('eBox will create a new table into its log database ' .
 					   'to store printers logs'),
@@ -93,11 +93,11 @@ sub actions
     ];
 }
 
-# Method: usedFiles 
+# Method: usedFiles
 #
-# 	Override EBox::ServiceModule::ServiceInterface::files
+# 	Override EBox::Module::Service::files
 #
-sub usedFiles 
+sub usedFiles
 {
     return [
 	{
@@ -114,9 +114,9 @@ sub usedFiles
 	];
 }
 
-# Method: enableActions 
+# Method: enableActions
 #
-# 	Override EBox::ServiceModule::ServiceInterface::enableActions
+# 	Override EBox::Module::Service::enableActions
 #
 sub enableActions
 {
@@ -127,42 +127,22 @@ sub enableActions
 #
 # Overrides:
 #
-#  <EBox::ServiceModule::ServiceInterface::enableService>
+#  <EBox::Module::Service::enableService>
 #
 sub enableService
 {
 	my ($self, $status) = @_;
-	
+
 	$self->SUPER::enableService($status);
 
-	if (_checkSambaInstalled()) {
-		my $samba = EBox::Global->modInstance('samba');
-		$samba->setPrinterService($status);
-	}
-}
-
-#  Method: serviceModuleName
-#
-#   Override EBox::ServiceModule::ServiceInterface::servivceModuleName
-#
-sub serviceModuleName
-{
-	return 'printers';
-}
-
-#  Method: enableModDepends
-#
-#   Override EBox::ServiceModule::ServiceInterface::enableModDepends
-#
-sub enableModDepends 
-{
-    return ['samba'];
+    my $samba = EBox::Global->modInstance('samba');
+    $samba->setPrinterService($status);
 }
 
 sub firewallHelper
 {
         my $self = shift;
-        if ($self->service) {
+        if ($self->isEnabled()) {
                 return new EBox::PrinterFirewall();
         }
         return undef;
@@ -187,13 +167,17 @@ sub writeOldCupsConf
 		push (@conf, $printer );
 	}
 
-	$self->writeConfFile(CUPSPRINTERS, 
-			'printers/printers.conf.mas', 
+	$self->writeConfFile(CUPSPRINTERS,
+			'printers/printers.conf.mas',
 			['printers' => \@conf]);
 
 }
 
-sub _setCupsConf
+# Method: actions
+#
+#	Override EBox::Module::Base::_setConf
+#
+sub _setConf
 {
 	my $self = shift;
 
@@ -211,31 +195,13 @@ sub _setCupsConf
 
 }
 
-sub isRunning 
+sub _daemons
 {
-	EBox::Service::running('ebox.cups');
-}
-
-sub _doDaemon
-{
-        my $self = shift;
-
-	my $service = $self->service();
-
-        if ($service and $self->isRunning()) {
-                EBox::Service::manage('ebox.cups','restart');
-        } elsif ($service) {
-                EBox::Service::manage('ebox.cups','start');
-        } elsif ($self->isRunning()) {
-                EBox::Service::manage('ebox.cups','stop');
+    return [
+        {
+            'name' => 'ebox.cups'
         }
-}
-
-sub _regenConfig
-{
-	my $self = shift;
-	$self->_setCupsConf();
-	$self->_doDaemon();
+    ];
 }
 
 sub summary
@@ -244,61 +210,10 @@ sub summary
 	return undef;
 }
 
-sub statusSummary
-{
-        my $self = shift;
-
-	my $smbrun = 1;
-	if (_checkSambaInstalled()) {
-                my $samba = EBox::Global->modInstance('samba');
-		$smbrun = $samba->isRunning;
-        }
-        return new EBox::Summary::Status('printers', __('Printer sharing'),
-                                ($self->isRunning and $smbrun), $self->service);
-}
-
-
-#   Function: setService 
-#
-#       Sets the printer service.
-#
-#   Parameters:
-#
-#       enabled - boolean. True enable, undef disable
-#
-sub setService # (enabled)
-{
-     my ($self, $active) = @_;
-
-	$self->SUPER::enableService($active);
-
-	if (_checkSambaInstalled()) {
-		my $samba = EBox::Global->modInstance('samba');
-		$samba->setPrinterService($active);
-	}
-
-}
-
-#   Function: service 
-#
-#       Returns if the printer service is enabled  
-#
-#   Returns:
-#
-#       boolean - true if enabled, otherwise undef      
-#
-sub service
-{
-        my $self = shift;
-		
-		return ($self->isEnabled());
-}
-
-
 sub manufacturers
 {
 	shift;
-	
+
 	my $db = new Foomatic::DB;
 	my @makes = sort($db->get_makes());
 	# Add Raw
@@ -323,10 +238,10 @@ sub _printerFromManuModel($$$)
 	shift;
 	my $maker = shift;
 	my $model = shift;
-	
+
 	my $db = new Foomatic::DB;
 	return $db->get_printer_from_make_model($maker, $model);
-}	
+}
 
 sub _printerIdDriver($$$)
 {
@@ -351,16 +266,16 @@ sub driversForPrinter($$)
 {
 	my $self = shift;
 	my $id = shift;
-	
+
 	my $printer = $self->_printerIdDriver($id);
 	if ($printer eq 'Raw') {
 		return ['Raw'];
 	}
 	my $db = new Foomatic::DB;
-	#my @drivers = grep(! /^(gimp.*)|(hpdj)/, 
+	#my @drivers = grep(! /^(gimp.*)|(hpdj)/,
 	my @drivers = $db->get_drivers_for_printer($printer);
 	if (@drivers) {
-		return \@drivers;	
+		return \@drivers;
 	} else {
 		return [];
 	}
@@ -370,12 +285,14 @@ sub driversForPrinter($$)
 sub menu
 {
 	my ($self, $root) = @_;
-	
+
 	my $folder = new EBox::Menu::Folder('name' => 'Printers',
-					    'text' => __('Printers'));
+					    'text' => $self->printableName(),
+                        'separator' => __('Office'),
+                        'order' => 550);
 
 	$folder->add(new EBox::Menu::Item('url' => 'Printers/AddPrinterUI',
-					  'text' => __('Add printer')));
+					  'text' => __('Add Printer')));
 
 	$folder->add(new EBox::Menu::Item('url' => 'Printers/AddPrinter',
 					  'text' => ''));
@@ -446,12 +363,12 @@ sub menu
 sub _printerNameExists($$)
 {
 	my ($self, $name) = @_;
-	
+
 	my @idprinters = $self->all_dirs("printers");
 	foreach my $dirid (@idprinters) {
 		my $idname = $self->get_string("$dirid/name");
 		return 1 if ($idname eq $name);
-	}	
+	}
 	return undef;
 }
 
@@ -462,7 +379,7 @@ sub _printerIdExists($$)
 	return $self->dir_exists("printers/$id");
 }
 
-sub _printerInfo($$) 
+sub _printerInfo($$)
 {
 	my ($self, $id) = @_;
 	unless ($self->_printerIdExists($id)) {
@@ -475,7 +392,7 @@ sub _printerInfo($$)
 	return  $self->hash_from_dir("printers/$id");
 }
 
-sub _printerConfigured($$) 
+sub _printerConfigured($$)
 {
 	my ($self, $id) = @_;
 	unless ($self->_printerIdExists($id)) {
@@ -513,7 +430,7 @@ sub printers
 	unless ($self->dir_exists("printers")){
 		return \@printers;
 	}
-	
+
 	my @idprinters = $self->all_dirs("printers");
 	foreach my $dirid (@idprinters) {
 		my $id = $dirid;
@@ -521,17 +438,17 @@ sub printers
 		next unless ($self->_printerConfigured($id));
 		my $name = $self->get_string("$dirid/name");
 		my $info = $self->manufacturer($id) . " " . $self->model($id);
-		push(@printers, 
+		push(@printers,
 			{ 'id' => $id, 'name' => "$name" , 'info' => "$info" });
 	}
-	return \@printers;	
+	return \@printers;
 }
 
 # Method: cleanTempPrinters
 #
-#  	Remove those printers which have not been fully configured	
+#  	Remove those printers which have not been fully configured
+#
 #
-# 	
 sub cleanTempPrinters
 {
 	my $self = shift;
@@ -550,16 +467,16 @@ sub removePrinter # (id)
 {
 	my $self = shift;
 	my $id = shift;
-	
+
 	unless ($self->_printerIdExists($id)) {
 		throw EBox::Exceptions::DataExists(
 					'data'  => __('Printer'),
 					'value' => "$id");
 	}
-	
+
 	$self->_removeCacheDrvOptions($id);
-	
-	if (_checkSambaInstalled() and $self->_printerConfigured($id)) {
+
+	if ($self->_printerConfigured($id)) {
 		my $samba = EBox::Global->modInstance('samba');
 		my $info = $self->_printerInfo($id);
 		$samba->delPrinter($info->{'name'});
@@ -573,7 +490,7 @@ sub addPrinter($$$)
 	unless (_checkPrinterName($name)) {
                 throw EBox::Exceptions::External
                         __("The printer's name contains characters not valid." .
-                        "Only alphanumeric characters are allowed");	
+                        "Only alphanumeric characters are allowed");
 	}
 	unless (grep(/^$method$/, SUPPORTEDMETHODS)) {
 		throw EBox::Exceptions::InvalidData('data'  => __('Method'),
@@ -584,15 +501,13 @@ sub addPrinter($$$)
 					'data'  => __('Name'),
 					'value' => "$name");
 	}
-	if (_checkSambaInstalled()) {	
-		my $samba = EBox::Global->modInstance('samba');
-		my $rsr = $samba->existsShareResource($name);
-		if ($rsr) {
-			throw EBox::Exceptions::External(
-			  __('The given name is alreaday used as ') . $rsr);
-		}
-	}
-	
+    my $samba = EBox::Global->modInstance('samba');
+    my $rsr = $samba->existsShareResource($name);
+    if ($rsr) {
+        throw EBox::Exceptions::External(
+          __('The given name is alreaday used as ') . $rsr);
+    }
+
 	my $id = $self->get_unique_id('p', 'printers');
 	$self->set_string("printers/$id/name", $name);
 	$self->set_bool("printers/$id/configured", undef);
@@ -605,7 +520,7 @@ sub _location ($$)
 {
 	my $self = shift;
 	my $id = shift;
-	
+
 	unless ($self->_printerIdExists($id)) {
 		throw EBox::Exceptions::DataNotFound('data'  => __('Printer'),
 						     'value' => "$id");
@@ -624,7 +539,7 @@ sub _location ($$)
 			$smburi = "guest:@".$smburi;
 		} elsif ($conf->{auth} eq 'anonymous') {
 		} elsif ($conf->{auth} eq 'user'){
-			$smburi = $conf->{user} . ":" . $conf->{passwd} . 
+			$smburi = $conf->{user} . ":" . $conf->{passwd} .
 				  "@" . "$smburi";
 		}
 		$location = "smb://$smburi";
@@ -633,8 +548,14 @@ sub _location ($$)
 		$location = "usb:/dev/usb/" . $conf->{dev};
 	} elsif ($conf->{method} eq 'parallel') {
 		$location = "parallel:/dev/" . $conf->{dev};
-	}
-	return $location;	
+       } elsif ($conf->{method} eq 'lpd') {
+           $location = "lpd://" . $conf->{host} . ":" . $conf->{port};
+       } elsif ($conf->{method} eq 'ipp') {
+            $location = "ipp://" . $conf->{host} . ":" . $conf->{port};
+       }
+
+
+	return $location;
 }
 
 sub methodConf($$)
@@ -646,7 +567,7 @@ sub methodConf($$)
 		throw EBox::Exceptions::DataNotFound('data'  => __('Printer'),
 						     'value' => "$id");
 	}
-	
+
 	unless ($self->dir_exists("printers/$id/conf")){
 		return undef;
 	}
@@ -657,7 +578,7 @@ sub setMethod($$$)
 {
 	my $self = shift;;
 	my $id = shift;
-	my $method = shift;;	
+	my $method = shift;;
 
 	unless ($self->_printerIdExists($id)) {
 		throw EBox::Exceptions::DataNotFound('data'  => __('Printer'),
@@ -667,7 +588,7 @@ sub setMethod($$$)
 		throw EBox::Exceptions::InvalidData('data'  => __('Method'),
 						    'value' => "$method");
 	}
-	
+
 	return if ($self->get_string("printers/$id/method") eq $method);
 	if ($self->dir_exists("printers/$id/conf")){
 		$self->delete_dir("printers/$id/conf");
@@ -680,12 +601,12 @@ sub setUSBPrinter($$$)
 	my $self = shift;
 	my $id = shift;
 	my $dev = shift ;
-	
+
 	unless ($self->_printerIdExists($id)) {
 		throw EBox::Exceptions::DataNotFound('data'  => __('Printer'),
 						     'value' => "$id");
 	}
-	
+
 	unless ($dev =~ /^usb\d$/) {
 		throw EBox::Exceptions::InvalidData
 			('data' => __('Device'), 'value' => $dev);
@@ -695,7 +616,7 @@ sub setUSBPrinter($$$)
 		throw EBox::Exceptions::External(
 				__("It is not a usb printer"));
 	}
-	
+
 	unless ($self->get_string("printers/$id/conf/dev" eq $dev)){
 		$self->set_string("printers/$id/conf/dev", $dev);
 	}
@@ -706,12 +627,12 @@ sub setParallelPrinter($$$)
 	my $self = shift;
 	my $id = shift;
 	my $dev = shift ;
-	
+
 	unless ($self->_printerIdExists($id)) {
 		throw EBox::Exceptions::DataNotFound('data'  => __('Printer'),
 						     'value' => "$id");
 	}
-	
+
 	unless ($dev =~ /^lp\d$/) {
 		throw EBox::Exceptions::InvalidData
 			('data' => __('Device'), 'value' => $dev);
@@ -721,7 +642,7 @@ sub setParallelPrinter($$$)
 		throw EBox::Exceptions::External(
 				__("It is not a parallel printer"));
 	}
-	
+
 	unless ($self->get_string("printers/$id/conf/dev" eq $dev)){
 		$self->set_string("printers/$id/conf/dev", $dev);
 	}
@@ -733,12 +654,12 @@ sub setNetworkPrinter($$$)
 	my $id = shift;
 	my $ip = shift ;
 	my $port = shift;
-	
+
 	unless ($self->_printerIdExists($id)) {
 		throw EBox::Exceptions::DataNotFound('data'  => __('Printer'),
 						     'value' => "$id");
 	}
-	
+
 	checkIP($ip, __('IP'));
 	checkPort($port, __('Port'));
 
@@ -747,14 +668,14 @@ sub setNetworkPrinter($$$)
 		throw EBox::Exceptions::External(
 				__("It is not a network printer"));
 	}
-	
+
 	unless ($self->get_string("printers/$id/conf/host" eq $ip)){
 		$self->set_string("printers/$id/conf/host", $ip);
 	}
 	unless ($self->get_int("printers/$id/conf/port") eq $port){
 		$self->set_int("printers/$id/conf/port", $port);
 	}
-	
+
 }
 
 sub setSambaPrinter # (id, resource, method, user, passwd)
@@ -765,18 +686,18 @@ sub setSambaPrinter # (id, resource, method, user, passwd)
 	my $auth = shift;
 	my $user= shift ;
 	my $passwd = shift;
-	
+
 	unless ($self->_printerIdExists($id)) {
 		throw EBox::Exceptions::DataNotFound('data'  => __('Printer'),
 						     'value' => "$id");
 	}
-	
+
 	my $method = $self->methodConf($id);
 	unless ($method->{'method'} eq 'samba') {
 		throw EBox::Exceptions::External(
 				__("It is not a samba printer"));
 	}
-	
+
 	unless ($self->get_string("printers/$id/conf/resource" eq $rsrc)){
 		$self->set_string("printers/$id/conf/resource", $rsrc);
 	}
@@ -789,7 +710,62 @@ sub setSambaPrinter # (id, resource, method, user, passwd)
 	unless ($self->get_string("printers/$id/conf/passwd") eq $passwd){
 		$self->set_string("printers/$id/conf/passwd", $passwd);
 	}
-	
+
+}
+
+sub setIPPPrinter
+{
+    my ($self, $id, $ip, $port) = @_;
+
+    unless ($self->_printerIdExists($id)) {
+        throw EBox::Exceptions::DataNotFound('data'  => __('Printer'),
+                                             'value' => "$id");
+    }
+
+    checkIP($ip, __('IP'));
+    checkPort($port, __('Port'));
+
+    my $method = $self->methodConf($id);
+    unless ($method->{'method'} eq 'ipp') {
+        throw EBox::Exceptions::External(
+                                         __("It is not a IPP printer"));
+    }
+
+    unless ($self->get_string("printers/$id/conf/host" eq $ip)){
+        $self->set_string("printers/$id/conf/host", $ip);
+    }
+    unless ($self->get_int("printers/$id/conf/port") eq $port){
+        $self->set_int("printers/$id/conf/port", $port);
+    }
+
+}
+
+
+sub setLPDPrinter
+{
+    my ($self, $id, $ip, $port) = @_;
+
+    unless ($self->_printerIdExists($id)) {
+        throw EBox::Exceptions::DataNotFound('data'  => __('Printer'),
+                                             'value' => "$id");
+    }
+
+    checkIP($ip, __('IP'));
+    checkPort($port, __('Port'));
+
+    my $method = $self->methodConf($id);
+    unless ($method->{'method'} eq 'lpd') {
+        throw EBox::Exceptions::External(
+                                         __("It is not a LPD printer"));
+    }
+
+    unless ($self->get_string("printers/$id/conf/host" eq $ip)){
+        $self->set_string("printers/$id/conf/host", $ip);
+    }
+    unless ($self->get_int("printers/$id/conf/port") eq $port){
+        $self->set_int("printers/$id/conf/port", $port);
+    }
+
 }
 
 sub _manufacturerExists($$)
@@ -809,13 +785,13 @@ sub manufacturer($$)
 {
 	my $self = shift;
 	my $id = shift;
-	
+
 	unless ($self->_printerIdExists($id)) {
 		throw EBox::Exceptions::DataNotFound('data'  => __('Printer'),
 						     'value' => "$id");
 	}
 
-	return $self->get_string("printers/$id/manufacturer");	
+	return $self->get_string("printers/$id/manufacturer");
 }
 
 sub setManufacturer($$$)
@@ -823,7 +799,7 @@ sub setManufacturer($$$)
 	my $self = shift;
 	my $id = shift;
 	my $maker = shift;
-	
+
 	unless ($self->_printerIdExists($id)) {
 		throw EBox::Exceptions::DataNotFound('data'  => __('Printer'),
 						     'value' => "$id");
@@ -832,7 +808,7 @@ sub setManufacturer($$$)
 		throw EBox::Exceptions::DataNotFound(
 			'data'  => __('Manufacturer'), 'value' => "$maker");
 	}
-	
+
 	$self->set_bool("printers/$id/raw", undef);
 	return if ($self->manufacturer($id) eq "$maker");
 
@@ -842,20 +818,20 @@ sub setManufacturer($$$)
 		$self->delete_dir("printers/$id/drvopts");
 	}
 
-	
+
 }
 
 sub model($$)
 {
 	my $self = shift;
 	my $id = shift;
-	
+
 	unless ($self->_printerIdExists($id)) {
 		throw EBox::Exceptions::DataNotFound('data'  => __('Printer'),
 						     'value' => "$id");
 	}
 
-	return $self->get_string("printers/$id/model");	
+	return $self->get_string("printers/$id/model");
 }
 
 sub setModel($$$)
@@ -863,7 +839,7 @@ sub setModel($$$)
 	my $self = shift;
 	my $id = shift;
 	my $model = shift;
-	
+
 	unless ($self->_printerIdExists($id)) {
 		throw EBox::Exceptions::DataNotFound('data'  => __('Printer'),
 						     'value' => "$id");
@@ -872,7 +848,7 @@ sub setModel($$$)
 		throw EBox::Exceptions::DataNotFound('data'  => __('Model'),
 						     'value' => "$model");
 	}
-	
+
 	$self->set_bool("printers/$id/raw", undef);
 	return if ($self->model($id) eq "$model");
 
@@ -889,13 +865,13 @@ sub driver($$)
 {
 	my $self = shift;
 	my $id = shift;
-	
+
 	unless ($self->_printerIdExists($id)) {
 		throw EBox::Exceptions::DataNotFound('data'  => __('Printer'),
 						     'value' => "$id");
 	}
 
-	return $self->get_string("printers/$id/driver");	
+	return $self->get_string("printers/$id/driver");
 }
 
 sub setDriver($$$)
@@ -903,7 +879,7 @@ sub setDriver($$$)
 	my $self = shift;
 	my $id = shift;
 	my $driver = shift;
-	
+
 	unless ($self->_printerIdExists($id)) {
 		throw EBox::Exceptions::DataNotFound('data'  => __('Printer'),
 						     'value' => "$id");
@@ -912,7 +888,7 @@ sub setDriver($$$)
 		throw EBox::Exceptions::DataNotFound('data'  => __('Model'),
 						     'value' => "$driver");
 	}
-	
+
 	$self->set_bool("printers/$id/raw", undef);
 	return if ($self->driver($id) eq "$driver");
 
@@ -924,7 +900,7 @@ sub setDriver($$$)
 
 }
 
-sub driverArgs($$) 
+sub driverArgs($$)
 {
 	my $self = shift;
 	my $id = shift;
@@ -933,14 +909,14 @@ sub driverArgs($$)
 		throw EBox::Exceptions::DataNotFound('data'  => __('Printer'),
 						     'value' => "$id");
 	}
-	
+
 	my $driver = $self->driver($id);
 	my $printer = $self->model($id);
 	my $manufacturer = $self->manufacturer($id);
 
 	my $printerid = $self->_printerFromManuModel($manufacturer, $printer);
 	$printerid or return [];
-	
+
 	my $db = new Foomatic::DB;
 	my $dat = $db->getdat($driver, $printerid);
 
@@ -964,7 +940,7 @@ sub driverOptions($$)
 			for my $key (keys %{$opts}){
 				$driveropts->{$key}->{value} = $opts->{$key};
 			}
-			
+
 		}
 	}
 
@@ -976,7 +952,7 @@ sub setDriverOptions($$$)
 	my $self = shift;
 	my $id  = shift;
 	my $defaults = shift;
-	
+
 	unless ($self->_printerIdExists($id)) {
 		throw EBox::Exceptions::DataNotFound('data'  => __('Printer'),
 						     'value' => "$id");
@@ -987,7 +963,7 @@ sub setDriverOptions($$$)
 	if ($self->dir_exists("printers/$id/drvopts")) {
 		$drvopts = $self->hash_from_dir("printers/$id/drvopts");
 	}
-		
+
 	for my $key (keys %{$defaults}) {
 		my $value = $defaults->{$key};
 		next if ($drvopts and ("$drvopts->{$key}" eq $value));
@@ -995,11 +971,9 @@ sub setDriverOptions($$$)
 	}
 
 	$self->_setPrinterConfigured($id, 1);
-	if (_checkSambaInstalled()) {
-		my $samba = EBox::Global->modInstance('samba');
-		my $info = $self->_printerInfo($id);
-		$samba->addPrinter($info->{'name'});
-	}
+    my $samba = EBox::Global->modInstance('samba');
+    my $info = $self->_printerInfo($id);
+    $samba->addPrinter($info->{'name'});
 }
 
 sub _checkDriverOpts # (id, options)
@@ -1009,13 +983,13 @@ sub _checkDriverOpts # (id, options)
 	my $opts = shift;
 
 	my $fileopts = $self->_driverOptionsFile($id);
-	
+
 	for my $opt (keys %{$opts}) {
 		unless(defined($fileopts->{$opt})) {
 			throw EBox::Exceptions::External(
 				$opt . " " . __('is not a valid option'));
 		}
-		
+
 		my $type = $fileopts->{$opt}->{'type'};
 		my $ok;
 		if ($type eq 'enum') {
@@ -1028,12 +1002,12 @@ sub _checkDriverOpts # (id, options)
 		} elsif (($type eq 'int') or ($type eq 'float')) {
 			my $value = $opts->{$opt};
 			if ($value =~ /\d+(\.\d+)?/) {
-				if (($value >=  $fileopts->{$opt}->{'min'}) and  
+				if (($value >=  $fileopts->{$opt}->{'min'}) and
 				    ($value <= $fileopts->{$opt}->{'max'})) {
 					$ok = 1;
 				}
 			}
-			
+
 		} elsif ($type eq 'bool') {
 			$ok = 1;
 		}
@@ -1050,7 +1024,7 @@ sub _driverOptionsFile($$)
 {
 	my $self = shift;
 	my $id = shift;
-	
+
 	unless ($self->_printerIdExists($id)) {
 		throw EBox::Exceptions::DataNotFound('data'  => __('Printer'),
 						     'value' => "$id");
@@ -1058,31 +1032,31 @@ sub _driverOptionsFile($$)
 
 	my $options = $self->_cacheDrvOptions($id);
 	return $options if $options;
-	
-	
+
+
 	my $printer = $self->model($id);
 	my $manufacturer = $self->manufacturer($id);
 	my $printerid = $self->_printerFromManuModel($manufacturer, $printer);
 	$printerid or return {};
-	
+
 	my $db = new Foomatic::DB;
 	my $dat = $db->getdat($self->driver($id), $printerid);
 	for my $key (keys %{$dat->{args_byname}}){
 		$options->{$key} = {
 			'text' => $dat->{args_byname}->{$key}->{comment},
 			'value' => $dat->{args_byname}->{$key}->{default} };
-		
+
 		# Values could be int, float, enum, or bool
 		# int and float have valid range
 		my $type = $dat->{args_byname}->{$key}->{'type'};
 		$options->{$key}->{'type'} = $type;
-		if (($type eq 'int') or ($type eq 'float')) { 
-			$options->{$key}->{'min'} =  
+		if (($type eq 'int') or ($type eq 'float')) {
+			$options->{$key}->{'min'} =
 					$dat->{args_byname}->{$key}->{'min'};
-			$options->{$key}->{'max'} =  
+			$options->{$key}->{'max'} =
 				 	 $dat->{args_byname}->{$key}->{'max'};
-		} 
-		
+		}
+
 		my @values;
 		for my $vals (@{$dat->{args_byname}->{$key}->{vals}}) {
 			my $text = $vals->{comment};
@@ -1090,7 +1064,7 @@ sub _driverOptionsFile($$)
         	}
         	$options->{$key}->{options} = \@values;
 	}
-	
+
 	$self->_saveCacheDrvOptions($id, $options);
 	return $options;
 }
@@ -1099,7 +1073,7 @@ sub _setDriverOptionsToFile($$)
 {
 	my $self = shift;
 	my $id  = shift;
-	
+
 	unless ($self->_printerIdExists($id)) {
 		throw EBox::Exceptions::DataNotFound('data'  => __('Printer'),
 						     'value' => "$id");
@@ -1107,7 +1081,7 @@ sub _setDriverOptionsToFile($$)
 	unless ($self->_printerConfigured($id)) {
 		throw EBox::Exceptions::External(__('Printer not configured'));
 	}
-	
+
 	my $printer = $self->model($id);
 	if ($printer eq 'Raw') {
 		return;
@@ -1118,7 +1092,7 @@ sub _setDriverOptionsToFile($$)
 
 	my $printerid = $self->_printerFromManuModel($manufacturer, $printer);
 	$printerid or return {};
-	
+
 	my $ppd = EBox::Config::tmp . "/$manufacturer-$printerid-$driver.ppd";
 	command("foomatic-ppdfile -w -p $printerid -d $driver > '$ppd'");
 	my $db = new Foomatic::DB;
@@ -1126,7 +1100,7 @@ sub _setDriverOptionsToFile($$)
 
 	for my $arg (keys %{$defaults}){
 		if (defined($db->{dat}->{args_byname}->{$arg})){
-			$db->{dat}->{args_byname}->{$arg}->{default} = 
+			$db->{dat}->{args_byname}->{$arg}->{default} =
 						     $defaults->{$arg}->{value};
 		} else {
 			throw EBox::Exceptions::External(
@@ -1155,7 +1129,7 @@ sub printerJobs # (printerid, completed)
 
 	my $info = $self->_printerInfo($id);
 	my $printer = $self->{'cups'}->getDestination($info->{'name'});
-	
+
 	my @jobs;
 	if ($printer) {
 		@jobs = $printer->getJobs(0, $completed);
@@ -1173,16 +1147,16 @@ sub cancelJob # (printername, jobid)
 	my $self = shift;
 	my $printer = shift;
 	my $jobid = shift;
-	
+
 	unless ($self->_printerNameExists($printer)) {
 		throw EBox::Exceptions::DataNotFound('data'  => __('Printer'),
 						     'value' => "$printer");
 	}
-	
+
 	cupsCancelJob($printer, $jobid);
 }
 
-sub usbDevices 
+sub usbDevices
 {
 	my $self;
 
@@ -1209,14 +1183,14 @@ sub parallelDevices
 # Returns:
 #
 # 	array ref - holding the printer id's
-# 	
+#
 sub networkPrinters
 {
 	my $self = shift;
 
 	my @ids;
 	foreach my $printer (@{$self->printers()}) {
-		my $conf = $self->methodConf($printer->{id});				
+		my $conf = $self->methodConf($printer->{id});
 		push (@ids, $printer->{id}) if ($conf->{method} eq 'network');
 	}
 
@@ -1228,7 +1202,7 @@ sub _saveCacheDrvOptions # (id, options)
 	my $self = shift;
 	my $id = shift;
 	my $options = shift;
-	
+
 	unless ($self->_printerIdExists($id)) {
 		throw EBox::Exceptions::DataNotFound('data'  => __('Printer'),
 						     'value' => "$id");
@@ -1243,12 +1217,12 @@ sub _cacheDrvOptions # (id)
 {
 	my $self = shift;
 	my $id = shift;
-	
+
 	unless ($self->_printerIdExists($id)) {
 		throw EBox::Exceptions::DataNotFound('data'  => __('Printer'),
 						     'value' => "$id");
 	}
-	
+
 	my $file = EBox::Config::tmp . "printer-$id.st";
 	unless ( -f "$file" ) {
 		return undef;
@@ -1262,12 +1236,12 @@ sub _removeCacheDrvOptions # (id)
 {
 	my $self = shift;
 	my $id = shift;
-	
+
 	my $file = EBox::Config::tmp . "printer-$id.st";
 	unless ( -f "$file" ) {
 		return undef;
 	}
-	
+
 	command("/bin/rm $file");
 }
 
@@ -1284,7 +1258,7 @@ sub tableInfo {
 	my @order = ('timestamp', 'job', 'printer', 'owner', 'event');
 	my $events = { 'queued' => __('Queued'), 'canceled' => __('Canceled') };
 
-	return {
+	return [{
 		'name' => __('Printers'),
 		'index' => 'printers',
 		'titles' => $titles,
@@ -1294,13 +1268,13 @@ sub tableInfo {
                 'filter' => ['printer', 'owner'],
                 'events' => $events,
                 'eventcol' => 'event'
-								
-	};
+
+	}];
 }
 sub logHelper
 {
 	my $self = shift;
-	
+
 	return (new EBox::PrinterLogHelper);
 }
 
@@ -1314,20 +1288,14 @@ sub _checkPrinterName ($)
         return 1;
 }
 
-sub _checkSambaInstalled 
-{
-	my $samba = EBox::Global->modInstance('samba');
-	return  $samba ? 1 : undef;
-}
-
 sub _mergeCupsConf
 {
 	my ($self) = @_;
 
-	my  $manager = new EBox::ServiceModule::Manager();
+	my  $manager = new EBox::ServiceManager();
         if ($manager->checkUserModifications()
             and $manager->skipModification(
-		$self->serviceModuleName(), CUPSPRINTERS)) {
+		$self->{'name'}, CUPSPRINTERS)) {
             EBox::info('Skipping modification of ' . CUPSPRINTERS);
             #return;
         }
@@ -1338,28 +1306,28 @@ sub _mergeCupsConf
 		my $cmd = 'cat ' . CUPSPRINTERS;
 		@file = @{root($cmd)};
 	}
-	my $startTag = START_TAG; 
+	my $startTag = START_TAG;
 	my $endTag = END_TAG;
-	
+
 	my @newFile;
 	my $copy = 1;
 	for my $line (@file) {
 		if ($line =~ /$startTag/) {
 			$copy = undef;
-		} 
+		}
 		push (@newFile, $line) if ($copy);
 		if ((not $copy) and $line =~ /$endTag/) {
 			$copy = 1;
 		}
 	}
-	
+
 	my $output;
 
-	my $interp = HTML::Mason::Interp->new(comp_root => 
+	my $interp = HTML::Mason::Interp->new(comp_root =>
 						EBox::Config::stubs,
 						out_method => \$output);
 	my $comp = $interp->make_component(
-			comp_file => 
+			comp_file =>
 			EBox::Config::stubs() . 'printers/printers.conf.mas');
 	my @conf;
 	my @idprinters = $self->all_dirs("printers");
@@ -1388,13 +1356,13 @@ sub _mergeCupsConf
 	root("cp $file " . CUPSPRINTERS);
 	close ($fd);
 
-        $manager->updateFileDigest($self->serviceModuleName(), CUPSPRINTERS);
+        $manager->updateFileDigest($self->{'name'}, CUPSPRINTERS);
 }
 
 # Method: fetchExternalCUPSPrinters
 #
 #	This method returns those printers that haven been configured
-#	by the user using CUPS and not our interface. 
+#	by the user using CUPS and not our interface.
 #
 # Returns:
 #
